==> jc-1.4.0.tar.gz: polyglot/frontend/AbstractPass.h <==
// public abstract class polyglot.frontend.AbstractPass

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4dca5983f7072958 polyglot_frontend_AbstractPass

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_frontend_AbstractPass_H_
#define _JC_polyglot_frontend_AbstractPass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_frontend_Pass__24ID$object;

// Typedefs
typedef struct _jc_polyglot_frontend_AbstractPass$sub_refs	_jc_polyglot_frontend_AbstractPass$sub_refs;
typedef struct _jc_polyglot_frontend_AbstractPass$sub_nonrefs	_jc_polyglot_frontend_AbstractPass$sub_nonrefs;
typedef struct _jc_polyglot_frontend_AbstractPass$refs	_jc_polyglot_frontend_AbstractPass$refs;
typedef struct _jc_polyglot_frontend_AbstractPass$nonrefs	_jc_polyglot_frontend_AbstractPass$nonrefs;
typedef struct _jc_polyglot_frontend_AbstractPass$object	_jc_polyglot_frontend_AbstractPass$object;

typedef const struct _jc_polyglot_frontend_AbstractPass$vmethods	_jc_polyglot_frontend_AbstractPass$vmethods;
typedef const struct _jc_polyglot_frontend_AbstractPass$vtable	_jc_polyglot_frontend_AbstractPass$vtable;
typedef const struct _jc_polyglot_frontend_AbstractPass$vtype	_jc_polyglot_frontend_AbstractPass$vtype;

// Constructors
extern void _jc_polyglot_frontend_AbstractPass$method$_init$2bdf2b720377758d(_jc_env *, struct _jc_polyglot_frontend_AbstractPass$object *, struct _jc_polyglot_frontend_Pass__24ID$object *);

// Virtual methods
extern struct _jc_polyglot_frontend_Pass__24ID$object *_jc_polyglot_frontend_AbstractPass$method$id$7164413dcc582d5e(_jc_env *, struct _jc_polyglot_frontend_AbstractPass$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_frontend_AbstractPass$method$name$e6acce026cadf81e(_jc_env *, struct _jc_polyglot_frontend_AbstractPass$object *);
extern jboolean _jc_polyglot_frontend_AbstractPass$method$run$1ec62afce18bd5ee(_jc_env *, struct _jc_polyglot_frontend_AbstractPass$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_frontend_AbstractPass$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_frontend_AbstractPass$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_AbstractPass$method_info$id$7164413dcc582d5e;
extern _jc_method _jc_polyglot_frontend_AbstractPass$method_info$name$e6acce026cadf81e;
extern _jc_method _jc_polyglot_frontend_AbstractPass$method_info$run$1ec62afce18bd5ee;
extern _jc_method _jc_polyglot_frontend_AbstractPass$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_frontend_AbstractPass$vmethods {
	struct _jc_polyglot_frontend_Pass__24ID$object	*(*id$7164413dcc582d5e)(_jc_env *, struct _jc_polyglot_frontend_AbstractPass$object *);
	struct _jc_java_lang_String$object	*(*name$e6acce026cadf81e)(_jc_env *, struct _jc_polyglot_frontend_AbstractPass$object *);
	jboolean	(*run$1ec62afce18bd5ee)(_jc_env *, struct _jc_polyglot_frontend_AbstractPass$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_frontend_AbstractPass$object *);
};

// Vtable
struct _jc_polyglot_frontend_AbstractPass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_AbstractPass$vmethods	polyglot_frontend_AbstractPass;
};

// Vtype
struct _jc_polyglot_frontend_AbstractPass$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_AbstractPass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_AbstractPass$sub_refs {
	struct _jc_polyglot_frontend_Pass__24ID$object	*id;
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_AbstractPass$refs {
    _jc_polyglot_frontend_AbstractPass$sub_refs	polyglot_frontend_AbstractPass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_AbstractPass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_AbstractPass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_AbstractPass$sub_nonrefs	polyglot_frontend_AbstractPass;
};

// Object instance structure
struct _jc_polyglot_frontend_AbstractPass$object {
	_jc_polyglot_frontend_AbstractPass$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_AbstractPass$vtype	*vtype;
	_jc_polyglot_frontend_AbstractPass$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_AbstractPass$vtype _jc_polyglot_frontend_AbstractPass$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_AbstractPass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_AbstractPass$class_object;

#endif	/* _JC_polyglot_frontend_AbstractPass_H_ */

==> jc-1.4.6.tar.gz: polyglot/frontend/AbstractPass.h <==
// public abstract class polyglot.frontend.AbstractPass

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4dca5983f7072958 polyglot_frontend_AbstractPass

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_frontend_AbstractPass_H_
#define _JC_polyglot_frontend_AbstractPass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_frontend_Pass__24ID$object;

// Typedefs
typedef struct _jc_polyglot_frontend_AbstractPass$sub_refs	_jc_polyglot_frontend_AbstractPass$sub_refs;
typedef struct _jc_polyglot_frontend_AbstractPass$sub_nonrefs	_jc_polyglot_frontend_AbstractPass$sub_nonrefs;
typedef struct _jc_polyglot_frontend_AbstractPass$refs	_jc_polyglot_frontend_AbstractPass$refs;
typedef struct _jc_polyglot_frontend_AbstractPass$nonrefs	_jc_polyglot_frontend_AbstractPass$nonrefs;
typedef struct _jc_polyglot_frontend_AbstractPass$object	_jc_polyglot_frontend_AbstractPass$object;

typedef const struct _jc_polyglot_frontend_AbstractPass$vmethods	_jc_polyglot_frontend_AbstractPass$vmethods;
typedef const struct _jc_polyglot_frontend_AbstractPass$vtable	_jc_polyglot_frontend_AbstractPass$vtable;
typedef const struct _jc_polyglot_frontend_AbstractPass$vtype	_jc_polyglot_frontend_AbstractPass$vtype;

// Constructors
extern void _jc_polyglot_frontend_AbstractPass$method$_init$2bdf2b720377758d(_jc_env *, struct _jc_polyglot_frontend_AbstractPass$object *, struct _jc_polyglot_frontend_Pass__24ID$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_polyglot_frontend_Pass__24ID$object *_jc_polyglot_frontend_AbstractPass$method$id$7164413dcc582d5e(_jc_env *, struct _jc_polyglot_frontend_AbstractPass$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_frontend_AbstractPass$method$name$e6acce026cadf81e(_jc_env *, struct _jc_polyglot_frontend_AbstractPass$object *) _JC_JCNI_ATTR;
extern jboolean _jc_polyglot_frontend_AbstractPass$method$run$1ec62afce18bd5ee(_jc_env *, struct _jc_polyglot_frontend_AbstractPass$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_frontend_AbstractPass$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_frontend_AbstractPass$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_AbstractPass$method_info$id$7164413dcc582d5e;
extern _jc_method _jc_polyglot_frontend_AbstractPass$method_info$name$e6acce026cadf81e;
extern _jc_method _jc_polyglot_frontend_AbstractPass$method_info$run$1ec62afce18bd5ee;
extern _jc_method _jc_polyglot_frontend_AbstractPass$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_frontend_AbstractPass$vmethods {
	struct _jc_polyglot_frontend_Pass__24ID$object	*(*id$7164413dcc582d5e)(_jc_env *, struct _jc_polyglot_frontend_AbstractPass$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*name$e6acce026cadf81e)(_jc_env *, struct _jc_polyglot_frontend_AbstractPass$object *) _JC_JCNI_ATTR;
	jboolean	(*run$1ec62afce18bd5ee)(_jc_env *, struct _jc_polyglot_frontend_AbstractPass$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_frontend_AbstractPass$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_frontend_AbstractPass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_AbstractPass$vmethods	polyglot_frontend_AbstractPass;
};

// Vtype
struct _jc_polyglot_frontend_AbstractPass$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_AbstractPass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_AbstractPass$sub_refs {
	struct _jc_polyglot_frontend_Pass__24ID$object	*id;
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_AbstractPass$refs {
    _jc_polyglot_frontend_AbstractPass$sub_refs	polyglot_frontend_AbstractPass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_AbstractPass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_AbstractPass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_AbstractPass$sub_nonrefs	polyglot_frontend_AbstractPass;
};

// Object instance structure
struct _jc_polyglot_frontend_AbstractPass$object {
	_jc_polyglot_frontend_AbstractPass$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_AbstractPass$vtype	*vtype;
	_jc_polyglot_frontend_AbstractPass$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_AbstractPass$vtype _jc_polyglot_frontend_AbstractPass$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_AbstractPass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_AbstractPass$class_object;

#endif	/* _JC_polyglot_frontend_AbstractPass_H_ */
